@@ -2,9 +2,12 @@ from ._version import VERSION
 
 # Classes and functions
 from .base import Lattice, Poset, Relation
-from .base_generation.exhaustive import all_lattices
-from .base_generation.random import lattice as random_lattice
-from .base_generation.random import poset as random_poset
+from .base_generation.exhaustive import iter_all_lattices
+from .base_generation.random import (
+    random_lattice,
+    random_poset,
+    random_f,
+)
 from .functional import f_lub, f_glb, f_iter
 
 # Modules
